@@ -28,7 +28,7 @@ class Baseline(dict):
             self.fixlets = {}
             self.tasks = {}
             self.analyses = {}
-            self.unique_id = None  # todo: rename, not really unique , maybe ref number?
+            # self.unique_id = None  # todo: rename, not really unique , maybe ref number?
 
         else:
 
@@ -46,6 +46,7 @@ class Baseline(dict):
             self.tasks = {}
             self.analyses = {}
             self.unique_id = None
+            self.deploy_and_run_id = 0
 
             logging.info(f"Starting parsing for baseline  {self.subject}.")
 
@@ -70,24 +71,28 @@ class Baseline(dict):
                         logging.info(f"Parsed {len(self.analyses)} analyses.")
                     else:
                         print("Parser couldn't parse")  # todo: Handle this better
-                        print(parsed_part)
+                        # print(parsed_part)
+                        logging.error(parsed_part)
                 except Exception as e:
                     logging.exception(f"Failed trying to parse {part}")
                     logging.exception(e)
 
             # Fixlets will share the same values
             try:
-                logging.info(f"Gathering baseline info from fixlets")
-                first_key = list(self.fixlets)[0]
-                self.source_release_date = self.fixlets.get(first_key).source_release_date
-                self.modification_time = self.fixlets.get(first_key).modication_time
-                self.cis_benchmark = self.fixlets.get(first_key).benchmark_version
-                self.xccdf_benchmark = self.fixlets.get(first_key).xccdf_benchmark
-                self.name = self.fixlets.get(first_key).source
+                logging.info(f"Gathering baseline info from fixlets count:{len(self.fixlets)}")
+                if len(self.fixlets) != 0:
+                    first_key = list(self.fixlets)[0]
+                    self.source_release_date = self.fixlets.get(first_key).source_release_date
+                    self.modification_time = self.fixlets.get(first_key).modication_time
+                    self.cis_benchmark = self.fixlets.get(first_key).benchmark_version
+                    self.xccdf_benchmark = self.fixlets.get(first_key).xccdf_benchmark
+                    self.name = self.fixlets.get(first_key).source
+
                 logging.info(f"Baseline Created.")
 
             except Exception as e:
-                print(e)
+                logging.info(e)
+                logging.info("Baseline doesn't have additional fixlets, this may be intentional")
 
     def __getattr__(self, attr):
         return self.get(attr)
@@ -132,13 +137,12 @@ class Baseline(dict):
             # if key in ["fixlets", "tasks", "analyses"]:
             payload[key] = value
 
-        payload["rule_id"] = self.rule_id
-        payload["source_release_date"] = self.source_release_date
-        payload["modification_time"] = self.modification_time
-        payload["cis_benchmark"] = self.cis_benchmark
-        payload["xccdf_benchmark"] = self.xccdf_benchmark
-        payload["name"] = self.name
-        payload["deploy_and_run_id"] = self.deploy_and_run_id
+        # payload["source_release_date"] = self.source_release_date
+        # payload["modification_time"] = self.modification_time
+        # payload["cis_benchmark"] = self.cis_benchmark
+        # payload["xccdf_benchmark"] = self.xccdf_benchmark
+        # payload["name"] = self.name
+        # payload["deploy_and_run_id"] = self.deploy_and_run_id
 
         return payload
 
@@ -208,6 +212,7 @@ class Baseline(dict):
     # def set_log_level(self, ):
     #     logging.getLogger().setLevel(logging.INFO)
 
+
 def find_type(payload):
     """Checks substring of payload to determine whether payload is """
     if "X-Fixlet-Type: Fixlet" in payload:
@@ -216,5 +221,9 @@ def find_type(payload):
         return Analysis(payload)
     elif "X-Fixlet-Type: Task" in payload:
         return Task(payload)
+    elif "x-fixlet-type: Client Task" in payload:
+        return Task(payload)
+    elif "x-fixlet-type: Client Fixlet" in payload:
+        return Fixlet(payload)
     else:
         return f"Error: {payload}"
